@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 #ifndef DUNE_GEOMETRY_REFINEMENT_PYRAMIDTRIANGULATION_CC
 #define DUNE_GEOMETRY_REFINEMENT_PYRAMIDTRIANGULATION_CC
 
@@ -65,7 +67,7 @@ namespace Dune
       class RefinementImp
       {
       public:
-        enum {dimension = dimension_};
+        constexpr static int dimension = dimension_;
 
         typedef CoordType ctype;
 
@@ -90,7 +92,7 @@ namespace Dune
 
         typedef Simplex::RefinementImp<dimension, CoordType> BackendRefinement;
 
-        enum { nKuhnSimplices = 2 };
+        constexpr static int nKuhnSimplices = 2;
       };
 
       template<int dimension, class CoordType>
@@ -175,7 +177,7 @@ namespace Dune
       protected:
         typedef typename Refinement::BackendRefinement BackendRefinement;
         typedef typename BackendRefinement::template Codim<dimension>::SubEntityIterator BackendIterator;
-        enum { nKuhnSimplices = 2 };
+        constexpr static int nKuhnSimplices = 2;
 
         int nIntervals_;
 
@@ -260,7 +262,7 @@ namespace Dune
       protected:
         typedef typename Refinement::BackendRefinement BackendRefinement;
         typedef typename BackendRefinement::template Codim<0>::SubEntityIterator BackendIterator;
-        enum { nKuhnSimplices = 2};
+        constexpr static int nKuhnSimplices = 2;
 
         int nIntervals_;
 
